@@ -512,8 +512,10 @@ void Session::run()
     // if a program was specified via setProgram(), but it couldn't be found (but a fallback was), print a warning
     if (exec != checkProgram(_program)) {
         terminalWarning(i18n("Could not find '%1', starting '%2' instead.  Please check your profile settings.", _program, exec));
+        _arguments.clear(); // ignore args if program is invalid
     } else if (exec != checkProgram(exec)) {
         terminalWarning(i18n("Could not find '%1', starting '%2' instead.  Please check your profile settings.", exec, checkProgram(exec)));
+        _arguments.clear(); // ignore args if program is invalid
     }
 
     // if no arguments are specified, fall back to program name
@@ -1859,7 +1861,8 @@ QList<int> Session::copyingSessions()
         if (auto copyToGroup = c->copyToGroup()) {
             QList<int> sessionIds;
 
-            for (auto session : copyToGroup->sessions()) {
+            const auto sessions = copyToGroup->sessions();
+            for (auto session : sessions) {
                 sessionIds.append(session->sessionId());
             }
 
@@ -2148,4 +2151,14 @@ SessionController *Session::controller()
     return nullptr;
 }
 
+// Only called during LoadLayout
+void Session::runCommandFromLayout(const QString &command) const
+{
+    if (isReadOnly()) {
+        return;
+    }
+
+    _emulation->sendText(command + QLatin1Char('\n'));
+}
+
 #include "moc_Session.cpp"
